@@ -3,23 +3,9 @@
 declare(strict_types=1);
 
 /**
- * @author Christoph Wurst <christoph@winzerhof-wurst.at>
- * @author Lukas Reschke <lukas@statuscode.ch>
- * @author Thomas Müller <thomas.mueller@tmit.eu>
- *
- * Mail
- *
- * This code is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License, version 3,
- * as published by the Free Software Foundation.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License, version 3,
- * along with this program.  If not, see <http://www.gnu.org/licenses/>
+ * SPDX-FileCopyrightText: 2016-2024 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-FileCopyrightText: 2013-2016 ownCloud Inc.
+ * SPDX-License-Identifier: AGPL-3.0-only
  *
  */
 return [
@@ -94,14 +80,24 @@ return [
 			'url' => '/api/accounts/{id}/signature',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'accounts#updateSmimeCertificate',
+			'url' => '/api/accounts/{id}/smime-certificate',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'accounts#getQuota',
 			'url' => '/api/accounts/{id}/quota',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'accounts#testAccountConnection',
+			'url' => '/api/accounts/{id}/test',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'autoConfig#queryIspdb',
-			'url' => '/api/autoconfig/ispdb/{email}',
+			'url' => '/api/autoconfig/ispdb/{host}/{email}',
 			'verb' => 'GET',
 		],
 		[
@@ -124,6 +120,11 @@ return [
 			'url' => '/api/tags/{id}',
 			'verb' => 'PUT'
 		],
+		[
+			'name' => 'tags#delete',
+			'url' => '/api/tags/{accountId}/delete/{id}',
+			'verb' => 'DELETE'
+		],
 		[
 			'name' => 'aliases#updateSignature',
 			'url' => '/api/accounts/{accountId}/aliases/{id}/signature',
@@ -179,6 +180,11 @@ return [
 			'url' => '/api/mailboxes/{id}/stats',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'mailboxes#repair',
+			'url' => '/api/mailboxes/{id}/repair',
+			'verb' => 'POST'
+		],
 		[
 			'name' => 'messages#downloadAttachment',
 			'url' => '/api/messages/{id}/attachment/{attachmentId}',
@@ -204,6 +210,11 @@ return [
 			'url' => '/api/messages/{id}/itineraries',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'messages#getDkim',
+			'url' => '/api/messages/{id}/dkim',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'messages#getSource',
 			'url' => '/api/messages/{id}/source',
@@ -244,11 +255,31 @@ return [
 			'url' => '/api/messages/{id}/move',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'messages#snooze',
+			'url' => '/api/messages/{id}/snooze',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'messages#unSnooze',
+			'url' => '/api/messages/{id}/unsnooze',
+			'verb' => 'POST'
+		],
 		[
 			'name' => 'messages#mdn',
 			'url' => '/api/messages/{id}/mdn',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'messages#smartReply',
+			'url' => '/api/messages/{messageId}/smartreply',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'messages#needsTranslation',
+			'url' => '/api/messages/{messageId}/needsTranslation',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'avatars#url',
 			'url' => '/api/avatars/url/{email}',
@@ -309,6 +340,21 @@ return [
 			'url' => '/api/settings/allownewaccounts',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'settings#setEnabledLlmProcessing',
+			'url' => '/api/settings/llm',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'settings#setImportanceClassificationEnabledByDefault',
+			'url' => '/api/settings/importance-classification-default',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'settings#setLayoutMessageView',
+			'url' => '/api/settings/layout-message-view',
+			'verb' => 'PUT'
+		],
 		[
 			'name' => 'trusted_senders#setTrusted',
 			'url' => '/api/trustedsenders/{email}',
@@ -324,6 +370,21 @@ return [
 			'url' => '/api/trustedsenders',
 			'verb' => 'GET'
 		],
+		[
+			'name' => 'internal_address#setAddress',
+			'url' => '/api/internalAddress/{address}',
+			'verb' => 'PUT'
+		],
+		[
+			'name' => 'internal_address#removeAddress',
+			'url' => '/api/internalAddress/{address}',
+			'verb' => 'DELETE'
+		],
+		[
+			'name' => 'internal_address#list',
+			'url' => '/api/internalAddress',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'sieve#updateAccount',
 			'url' => '/api/sieve/account/{id}',
@@ -349,20 +410,138 @@ return [
 			'url' => '/api/thread/{id}',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'thread#snooze',
+			'url' => '/api/thread/{id}/snooze',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'thread#unSnooze',
+			'url' => '/api/thread/{id}/unsnooze',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'thread#summarize',
+			'url' => '/api/thread/{id}/summary',
+			'verb' => 'GET'
+		],
+		[
+			'name' => 'thread#generateEventData',
+			'url' => '/api/thread/{id}/eventdata',
+			'verb' => 'GET'
+		],
 		[
 			'name' => 'outbox#send',
 			'url' => '/api/outbox/{id}',
 			'verb' => 'POST'
 		],
+		[
+			'name' => 'outbox#createFromDraft',
+			'url' => '/api/outbox/from-draft/{id}',
+			'verb' => 'POST'
+		],
+		[
+			'name' => 'googleIntegration#configure',
+			'url' => '/api/integration/google',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'googleIntegration#unlink',
+			'url' => '/api/integration/google',
+			'verb' => 'DELETE',
+		],
+		[
+			'name' => 'googleIntegration#oauthRedirect',
+			'url' => '/integration/google-auth',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'microsoftIntegration#configure',
+			'url' => '/api/integration/microsoft',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'microsoftIntegration#unlink',
+			'url' => '/api/integration/microsoft',
+			'verb' => 'DELETE',
+		],
+		[
+			'name' => 'microsoftIntegration#oauthRedirect',
+			'url' => '/integration/microsoft-auth',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'list#unsubscribe',
+			'url' => '/api/list/unsubscribe/{id}',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'drafts#move',
+			'url' => '/api/drafts/move/{id}',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'outOfOffice#getState',
+			'url' => '/api/out-of-office/{accountId}',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'outOfOffice#update',
+			'url' => '/api/out-of-office/{accountId}',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'outOfOffice#followSystem',
+			'url' => '/api/out-of-office/{accountId}/follow-system',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'followUp#checkMessageIds',
+			'url' => '/api/follow-up/check-message-ids',
+			'verb' => 'POST',
+		],
+		[
+			'name' => 'textBlockShares#getTextBlockShares',
+			'url' => '/api/textBlocks/{id}/shares',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'actionStep#findAllStepsForAction',
+			'url' => '/api/action-step/{actionId}/steps',
+			'verb' => 'GET'
+		],
 	],
 	'resources' => [
 		'accounts' => ['url' => '/api/accounts'],
 		'aliases' => ['url' => '/api/accounts/{accountId}/aliases'],
 		'autoComplete' => ['url' => '/api/autoComplete'],
+		'drafts' => ['url' => '/api/drafts'],
 		'localAttachments' => ['url' => '/api/attachments'],
 		'mailboxes' => ['url' => '/api/mailboxes'],
 		'messages' => ['url' => '/api/messages'],
 		'outbox' => ['url' => '/api/outbox'],
 		'preferences' => ['url' => '/api/preferences'],
-	]
+		'smimeCertificates' => ['url' => '/api/smime/certificates'],
+		'textBlock' => ['url' => '/api/textBlocks'],
+		'textBlockShares' => ['url' => '/api/textBlockshares'],
+		'quickActions' => ['url' => '/api/quick-actions'],
+		'actionStep' => ['url' => '/api/action-step'],
+	],
+	'ocs' => [
+		[
+			'name' => 'messageApi#get',
+			'url' => '/message/{id}',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'messageApi#getRaw',
+			'url' => '/message/{id}/raw',
+			'verb' => 'GET',
+		],
+		[
+			'name' => 'messageApi#getAttachment',
+			'url' => '/message/{id}/attachment/{attachmentId}',
+			'verb' => 'GET',
+		],
+	],
 ];
