@@ -77,6 +77,7 @@ OC.L10N.register(
     "Favorite" : "Gunsteling",
     "Back" : "Terug",
     "All day" : "Heeldag",
+    "Attendees" : "Bywoners",
     "Description" : "Beskrywing",
     "Create" : "Skep",
     "Select" : "Kies",
@@ -107,6 +108,7 @@ OC.L10N.register(
     "Message source" : "Boodskapbron",
     "Recipient" : "Ontvanger",
     "Priority" : "Prioriteit",
+    "delete" : "skrap",
     "Reset" : "Herstel",
     "Client ID" : "Klant-ID",
     "User" : "Gebruiker",
@@ -115,6 +117,7 @@ OC.L10N.register(
     "Valid until" : "Geldig tot",
     "Certificate" : "Sertifikaat",
     "Submit" : "Dien in",
+    "Shared" : "Gedeel",
     "Connect your mail account" : "Koppel u posrekening",
     "All" : "Alle",
     "Drafts" : "Konsepte",
@@ -128,7 +131,6 @@ OC.L10N.register(
     "Forwarding to %s" : "Stuur aan na %s",
     "Click here if you are not automatically redirected within the next few seconds." : "Klik hier indien u nie binne die volgende paar sekondes outomaties herverwys word nie.",
     "Redirect" : "Herverwys",
-    "The link leads to %s" : "Die skakel lei na %s",
-    "Actions" : "Aksies"
+    "The link leads to %s" : "Die skakel lei na %s"
 },
 "nplurals=2; plural=(n != 1);");
