@@ -245,12 +245,11 @@ OC.L10N.register(
     "Untitled event" : "Eventu ensin títulu",
     "Airplane" : "Avión",
     "Train" : "Tren",
-    "Flag" : "Bandera",
-    "Operator" : "Operador",
     "contains" : "contién",
     "matches" : "concasa",
-    "Filter name" : "Nome de la peñera",
     "Priority" : "Prioridá",
+    "delete" : "desaniciar",
+    "Edit" : "Editar",
     "Error saving config" : "Hebo un error al guardar la configuración",
     "Anti Spam Service" : "Serviciu de antispam",
     "Gmail integration" : "Integración con Gmail",
@@ -310,6 +309,8 @@ OC.L10N.register(
     "Error loading message" : "Hebo un error al cargar el mensaxe",
     "Redirect" : "Redirixir",
     "The link leads to %s" : "L'enllaz lleva a %s",
-    "Go to newest message" : "Dir al mensaxe más nuevu"
+    "Flag" : "Bandera",
+    "Operator" : "Operador",
+    "Filter name" : "Nome de la peñera"
 },
 "nplurals=2; plural=(n != 1);");
