@@ -26,15 +26,17 @@ OC.L10N.register(
     "Signature" : "Подпіс",
     "Default folders" : "Прадвызначаныя папкі",
     "Filters" : "Фільтры",
+    "Quick actions" : "Хуткія дзеянні",
     "Go back" : "Назад",
     "Email address" : "Адрас электроннай пошты",
     "Cancel" : "Скасаваць",
     "Accounts" : "Уліковыя запісы",
     "General" : "Агульныя",
+    "Layout" : "Макет",
     "Sorting" : "Сартаванне",
     "Privacy and security" : "Прыватнасць і бяспека",
     "S/MIME" : "S/MIME",
-    "About" : "Аб гэтым",
+    "About" : "Аб праграме",
     "Keyboard shortcuts" : "Спалучэнні клавіш",
     "Archive" : "Архіў",
     "Delete" : "Выдаліць",
@@ -63,19 +65,25 @@ OC.L10N.register(
     "Rich text" : "Фарматаваны тэкст",
     "No messages in this folder" : "У гэтай папцы няма паведамленняў",
     "No messages" : "Няма паведамленняў",
+    "Tomorrow – {timeLocale}" : "Заўтра – {timeLocale}",
     "Encrypted message" : "Зашыфраванае паведамленне",
     "Favorite" : "Абранае",
+    "Unread" : "Непрачытанае",
     "Read" : "Чытаць",
     "Edit tags" : "Рэдагаваць тэгі",
     "Delete message" : "Выдаліць паведамленне",
     "More actions" : "Больш дзеянняў",
     "Back" : "Назад",
+    "Mark as unread" : "Пазначыць як непрачытанае",
+    "Mark as read" : "Пазначыць як прачытанае",
+    "Attendees" : "Удзельнікі",
     "Description" : "Апісанне",
     "Create" : "Стварыць",
     "Select" : "Выбраць",
     "Comment" : "Каментарый",
     "Accept" : "Прыняць",
     "Decline" : "Адхіліць",
+    "More options" : "Больш параметраў",
     "Remove" : "Выдаліць",
     "Last hour" : "Апошняя гадзіна",
     "Today" : "Сёння",
@@ -83,6 +91,7 @@ OC.L10N.register(
     "Last week" : "Мінулы тыдзень",
     "Last month" : "Мінулы месяц",
     "Choose target folder" : "Выберыце мэтавую папку",
+    "Other" : "Іншае",
     "Forward" : "Пераслаць",
     "Move message" : "Перамясціць паведамленне",
     "Translate" : "Перакласці",
@@ -127,7 +136,7 @@ OC.L10N.register(
     "Date" : "Дата",
     "Tags" : "Тэгі",
     "Last 7 days" : "Апошнія 7 дзён",
-    "Custom" : "Скарыстаць",
+    "Custom" : "Карыстальніцкі",
     "Not found" : "Не знойдзена",
     "Newest message" : "Апошняе паведамленне",
     "Please select languages to translate to and from" : "Выберыце, з якой мовы на якую перакладаць",
@@ -141,10 +150,12 @@ OC.L10N.register(
     "Translate to" : "Перакласці на",
     "Translating" : "Пераклад",
     "Copy translated text" : "Скапіяваць перакладзены тэкст",
+    "Untitled event" : "Падзея без назвы",
     "Train" : "Цягнік",
-    "Flag" : "Сцяг",
     "Delete filter" : "Выдаліць фільтр",
-    "Operator" : "Аператар",
+    "Tag" : "Тэг",
+    "delete" : "выдаліць",
+    "Edit" : "Рэдагаваць",
     "Reset" : "Скінуць",
     "Client ID" : "Ідэнтыфікатар кліента",
     "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} на {host}:{port} (шыфраванне {ssl})",
@@ -160,6 +171,7 @@ OC.L10N.register(
     "S/MIME certificates" : "Сертыфікаты S/MIME",
     "Certificate name" : "Назва сертыфіката",
     "E-mail address" : "Адрас электроннай пошты",
+    "Valid until" : "Дзейнічае да",
     "Delete certificate" : "Выдаліць сертыфікат",
     "PKCS #12 Certificate" : "Сертыфікат PKCS #12",
     "PEM Certificate" : "Сертыфікат PEM",
@@ -189,6 +201,8 @@ OC.L10N.register(
     "There was a problem loading {tag}{name}{endtag}" : "Узнікла праблема з загрузкай {tag}{name}{endtag}",
     "Could not load your message" : "Не ўдалося загрузіць ваша паведамленне",
     "Could not load the message" : "Не ўдалося загрузіць паведамленне",
-    "Error loading message" : "Памылка пры загрузцы паведамлення"
+    "Error loading message" : "Памылка пры загрузцы паведамлення",
+    "Flag" : "Сцяг",
+    "Operator" : "Аператар"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
