@@ -80,7 +80,7 @@ OC.L10N.register(
     "Automated reply to incoming messages. If someone sends you several messages, this automated reply will be sent at most once every 4 days." : "Automatisk svar på indgående beskeder. Hvis nogen sender dig flere beskeder, sendes dette automatiske svar højst en gang hver 4. dag.",
     "Filters" : "Filtre",
     "Mail server" : "Mail server",
-    "Update alias" : "Opdater alias",
+    "Update alias" : "Opdatér alias",
     "Show update alias form" : "Vis formular til opdateringsalias",
     "Delete alias" : "Slet alias",
     "Go back" : "Gå tilbage",
@@ -114,7 +114,7 @@ OC.L10N.register(
     "Delete" : "Slet",
     "Search" : "Søg",
     "Send" : "Send",
-    "Refresh" : "Opdater",
+    "Refresh" : "Opdatér",
     "Ok" : "OK",
     "Encrypt with S/MIME and send later" : "Krypter med S/MIME og send senere",
     "Encrypt with S/MIME and send" : "Krypter med S/MIME og send",
@@ -183,13 +183,13 @@ OC.L10N.register(
     "Unimportant" : "Ikke vigtig",
     "Mark not spam" : "Marker ikke spam",
     "Mark as spam" : "Marker som spam",
-    "Edit tags" : "Rediger mærker",
+    "Edit tags" : "Redigér mærker",
     "Move thread" : "Flyt tråden",
     "Delete thread" : "Slet tråd",
     "Delete message" : "Slet besked",
     "More actions" : "Flere handlinger",
     "Back" : "Tilbage",
-    "Edit as new message" : "Rediger som ny besked",
+    "Edit as new message" : "Redigér som ny besked",
     "Create task" : "Opret opgave",
     "Download message" : "Download besked",
     "Load more" : "Hent flere",
@@ -324,11 +324,11 @@ OC.L10N.register(
     "Message source" : "Beskedens kildekode",
     "Saving new tag name …" : "Gemmer nyt tag navn ...",
     "Tag already exists" : "Mærket eksisterer allerede",
-    "Add tag" : "Tilføj Tag",
+    "Add tag" : "Tilføj tag",
     "Loading thread" : "Indlæser tråd",
     "Not found" : "Ikke fundet",
-    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME-signatur. Meddelelsen er ikke ændret, siden den blev sendt.",
-    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME-signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
+    "This message contains a verified digital S/MIME signature. The message wasn't changed since it was sent." : "Denne meddelelse indeholder en verificeret digital S/MIME signatur. Meddelelsen er ikke blevet ændret, siden den blev sendt.",
+    "This message contains an unverified digital S/MIME signature. The message might have been changed since it was sent or the certificate of the signer is untrusted." : "Denne meddelelse indeholder en ubekræftet digital S/MIME signatur. Meddelelsen kan være blevet ændret, siden den blev sendt, eller der er ikke tillid til underskriverens certifikat.",
     "Reply all" : "Besvar alle",
     "Reply to sender only" : "Besvar kun afsender",
     "Translate from" : "Oversæt fra",
@@ -343,10 +343,11 @@ OC.L10N.register(
     "Train" : "Tog",
     "Recipient" : "Modtager",
     "New filter" : "Nyt filter",
-    "Operator" : "Operatør",
     "contains" : "indeholder",
     "matches" : "er lig med",
     "Priority" : "Prioritet",
+    "delete" : "Slet",
+    "Edit" : "Redigér",
     "Reset" : "Nulstil",
     "Client ID" : "Klient ID",
     "Client secret" : "Klienthemmelighed",
@@ -366,7 +367,7 @@ OC.L10N.register(
     "Delete certificate" : "Slet certifikat",
     "No certificate imported yet" : "Intet certifikat importeret endnu",
     "Import certificate" : "Importér certifikat",
-    "Import S/MIME certificate" : "Importer S/MIME-certifikat",
+    "Import S/MIME certificate" : "Importér S/MIME-certifikat",
     "PKCS #12 Certificate" : "PKCS #12 Certifikat",
     "PEM Certificate" : "PEM Certifikat",
     "Certificate" : "Certifikat",
@@ -375,6 +376,7 @@ OC.L10N.register(
     "Submit" : "Send",
     "Group" : "Gruppe",
     "Shared" : "Delt",
+    "Edit {title}" : "Redigér {title}",
     "Shares" : "Delinger",
     "Insert" : "Indsæt",
     "Account connected" : "Kontoen er tilknyttet",
@@ -406,6 +408,6 @@ OC.L10N.register(
     "The link leads to %s" : "Linket fører til %s",
     "Continue to %s" : "Videre til %s",
     "Looking for a way to encrypt your emails?" : "Leder du efter en måde at kryptere dine e-mails på?",
-    "Go to newest message" : "Gå til nyeste besked"
+    "Operator" : "Operatør"
 },
 "nplurals=2; plural=(n != 1);");
