@@ -333,13 +333,14 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} από {depStation} προς {arrStation}",
     "Train from {depStation} to {arrStation}" : "Τρένο από {depStation} προς {arrStation}",
     "Train" : "Τρένο",
-    "Flag" : "Σημαία",
     "Recipient" : "Παραλήπτης",
     "Delete filter" : "Διαγραφή φίλτρου",
-    "Operator" : "Διαχειριστής",
     "contains" : "περιέχει",
     "matches" : "ταιριάζει",
     "Priority" : "Προτεραιότητα",
+    "Tag" : "Ετικέτα",
+    "delete" : "διαγραφή",
+    "Edit" : "Επεξεργασία",
     "Mail app" : "Εφαρμογή αλληλογραφίας",
     "The mail app allows users to read mails on their IMAP accounts." : "Η εφαρμογή ταχυδρομείου επιτρέπει στους χρήστες να διαβάζουν μηνύματα από τους λογαριασμούς τους IMAP.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Εδώ μπορείτε να βρείτε ρυθμίσεις για το περιστατικό. Οι συγκεκριμένες ρυθμίσεις χρήστη βρίσκονται στην ίδια την εφαρμογή (κάτω αριστερή γωνία).",
@@ -392,6 +393,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Κάντε κλικ εδώ εάν δεν ανακατευθυνθείτε αυτόματα μέσα σε λίγα δευτερόλεπτα.",
     "Redirect" : "Ανακατεύθυνση",
     "The link leads to %s" : "Αυτός ο σύνδεσμος οδηγεί στο %s",
-    "Continue to %s" : "Συνέχεια στο %s"
+    "Continue to %s" : "Συνέχεια στο %s",
+    "Flag" : "Σημαία",
+    "Operator" : "Διαχειριστής"
 },
 "nplurals=2; plural=(n != 1);");
