@@ -161,6 +161,8 @@ OC.L10N.register(
     "Recipient" : "Ricevonto",
     "matches" : "kongruas kun",
     "Priority" : "Prioritato",
+    "delete" : "forigi",
+    "Edit" : "Modifi",
     "Mail app" : "Retpoŝtprogrameto",
     "Reset" : "Restarigi",
     "Client ID" : "Klientidentigilo",
