@@ -167,6 +167,8 @@ OC.L10N.register(
     "Recipient" : "Destinatario",
     "matches" : "coincide",
     "Priority" : "Prioridad",
+    "delete" : "borrar",
+    "Edit" : "Editar",
     "Reset" : "Restablecer",
     "Client ID" : "ID del cliente",
     "Client secret" : "Secreto del cliente",
