@@ -98,6 +98,7 @@ OC.L10N.register(
     "The autoresponder uses Sieve, a scripting language supported by many email providers. If you're unsure whether yours does, check with your provider. If Sieve is available, click the button to go to the settings and enable it." : "Automaatvastaja on loodud Sieve skriptimiskeeles ja tavaliselt on selline võimalus toetatud paljude e-posti teenuste puhul. Kui sa pole enda omas kindel, siis palun küsi neilt üle. Kui Sieve on kasutatav, siis klõpsi järgnevat nuppu ja võta ta seadistustest kasutusele.",
     "Go to Sieve settings" : "Ava Sieve seadistused",
     "Filters" : "Filtrid",
+    "Quick actions" : "Kiirtoimingud",
     "Sieve script editor" : "Sieve skriptikoostaja",
     "Mail server" : "E-posti server",
     "Sieve server" : "Sieve server",
@@ -256,6 +257,10 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Lisa meeldetuletus selleks nädalavahetuseks",
     "Next week – {timeLocale}" : "Järgmisel nädalal – {timeLocale}",
     "Set reminder for next week" : "Lisa meeldetuletus järgmiseks nädalaks",
+    "Could not apply tag, configured tag not found" : "Sildi lisamine ei õnnestunud, seadistatud silti ei leidu",
+    "Could not move thread, destination mailbox not found" : "Jutulõnga teisaldamine ei õnnestunud, sihtpostkasti ei leidu",
+    "Could not execute quick action" : "Kiirtoimingu käivitamine ei õnnestu",
+    "Quick action executed" : "Kiirtoiming on käivitatud",
     "No trash folder configured" : "Prügikasti kaust on määramata",
     "Could not delete message" : "Kirja kustutamine ei õnnestunud",
     "Could not archive message" : "Kirja arhiveerimine ei õnnestunud",
@@ -289,6 +294,8 @@ OC.L10N.register(
     "Reply with meeting" : "Vasta saates koosoleku teavet",
     "Create task" : "Loo ülesanne",
     "Download message" : "Laadi kiri alla",
+    "Back to all actions" : "Tagasi kõikide toimingute juurde",
+    "Manage quick actions" : "Halda kiirtoiminguid",
     "Load more" : "Laadi veel",
     "_Mark {number} read_::_Mark {number} read_" : ["Märgi {number} loetuks","Märgi {number} loetuks"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Märgi {number} mitteloetuks","Märgi {number} mitteloetuks"],
@@ -624,8 +631,6 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Rong: {depStation} → {arrStation}",
     "Train" : "Rong",
     "Delete action" : "Kustuta tegevus",
-    "Flag" : "Märgi",
-    "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
     "Sender" : "Saatja",
     "Recipient" : "Saaja",
     "Create a new mail filter" : "Koosta uus e-posti filter",
@@ -641,27 +646,33 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Halda e-kirjade kaost. Filtrid aitavad sul olulist esile tõsta ja müra eemaldada.",
     "Filter is active" : "Filter on kasutusel",
     "Filter is not active" : "Filter pole kasutusel",
-    "Operator" : "Operaator",
     "If all the conditions are met, the actions will be performed" : "Kui kõik tingimused vastavad siis, need tegevused käivitatakse",
     "If any of the conditions are met, the actions will be performed" : "Kui mõni tingimus vastab siis, need tegevused käivitatakse",
-    "is exactly" : "on täpselt",
     "contains" : "sisaldab",
     "matches" : "kattub",
-    "Delete test" : "Kustuta test",
-    "Update mail filter" : "Uuenda e-posti filtrit",
-    "Filter name" : "Filtri nimi",
-    "If all the conditions are met" : "Kui kõik tingimused on täidetud",
-    "If any of the conditions are met" : "Kui mõni tingimutest on täidetud",
+    "is exactly" : "on täpselt",
     "Add condition" : "Lisa tingimus",
-    "Then perform these actions" : "Seejärel käivita need tegevused",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "Tegevused käivituvad, kui konkreetse testi vastus on tõene. Saadaval on järgnevad tegevused:",
-    "Moves the message into a specified folder." : "Teisaldab kirja etteantud kausta.",
-    "Adds a flag to the message." : "Lisab kirjale märgistuse.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Lõpetab Sieve skripti töö. Peale seda ei töödelda ühtegi järgnevat tingimust.",
     "Add action" : "Lisa tegevus",
     "Priority" : "Olulisus",
     "Enable filter" : "Kasuta filtrit",
-    "Save filter" : "Salvesta filter",
+    "Tag" : "Silt",
+    "delete" : "kustuta",
+    "Edit quick action" : "Muuda kiirtoimingut",
+    "Add quick action" : "Lisa kiirtoiming",
+    "Quick action deleted" : "Kiirtoiming on kustutatud",
+    "Failed to delete quick action" : "Kiirtoimingu kustutamine ei õnnestunud",
+    "Failed to update quick action" : "Kiirtoimingu uuendamine ei õnnestunud",
+    "Failed to update step in quick action" : "Kiirtoimingu sammu uuendamine ei õnnestunud",
+    "Quick action updated" : "Kiirtoiming on uuendatud",
+    "Failed to create quick action" : "Kiirtoimingu loomine ei õnnestunud",
+    "Failed to add steps to quick action" : "Kiirtoimingule sammude lisamine ei õnnestunud",
+    "Quick action created" : "Kiirtoiming on loodud",
+    "Failed to delete action step" : "Toimingu sammu kustutamine ei õnnestunud",
+    "No quick actions yet." : "Ühtegi kiirtoimingut veel pole",
+    "Edit" : "Muuda",
+    "Quick action name" : "Kiirtoimingu nimi",
+    "Do the following actions" : "Tee järgnevad toimingud",
+    "Add another action" : "Lisa veel üks toiming",
     "Successfully updated config for \"{domain}\"" : "„{domain}“ domeeni seadistuste uuendamine õnnestus",
     "Error saving config" : "Viga seadistuste salvestamisel",
     "Saved config for \"{domain}\"" : "„{domain}“ domeeni seadistused on salvestatud",
@@ -805,6 +816,19 @@ OC.L10N.register(
     "Looking for a way to encrypt your emails?" : "Kas otsid viisi oma kirjade krüptimiseks?",
     "Install Mailvelope browser extension" : "Paigalda Mailvelope'i brauserilaiendus",
     "Enable Mailvelope for the current domain" : "Võta Mailvelope selle domeeni puhul kasutusele!",
-    "Go to newest message" : "Mine viimase kirja juurde"
+    "Flag" : "Märgi",
+    "The stop action ends all processing" : "See tegevus lõpetab kogu töötlemise",
+    "Operator" : "Operaator",
+    "Delete test" : "Kustuta test",
+    "Update mail filter" : "Uuenda e-posti filtrit",
+    "Filter name" : "Filtri nimi",
+    "If all the conditions are met" : "Kui kõik tingimused on täidetud",
+    "If any of the conditions are met" : "Kui mõni tingimutest on täidetud",
+    "Then perform these actions" : "Seejärel käivita need tegevused",
+    "Actions are triggered when the specified tests are true. The following actions are available:" : "Tegevused käivituvad, kui konkreetse testi vastus on tõene. Saadaval on järgnevad tegevused:",
+    "Moves the message into a specified folder." : "Teisaldab kirja etteantud kausta.",
+    "Adds a flag to the message." : "Lisab kirjale märgistuse.",
+    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Lõpetab Sieve skripti töö. Peale seda ei töödelda ühtegi järgnevat tingimust.",
+    "Save filter" : "Salvesta filter"
 },
 "nplurals=2; plural=(n != 1);");
