@@ -567,8 +567,6 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "Trena {depStation} geltokitik {arrStation} geltokira",
     "Train" : "Trena",
     "Delete action" : "Ezabatu ekintza",
-    "Flag" : "Bandera",
-    "The stop action ends all processing" : "Gelditze-ekintzak prozesua amaitzen du.",
     "Recipient" : "Hartzailea",
     "Delete filter" : "Ezabatu iragazkia",
     "Delete mail filter {filterName}?" : "Ezabatu {filterName} posta-iragazkia?",
@@ -581,23 +579,15 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Kontrolatu zure posta elektronikoaren kaosa. Iragazkiek garrantzitsuena lehenestu eta zaborra ezabatzen laguntzen dizute.",
     "Filter is active" : "Iragazkia gaituta dago",
     "Filter is not active" : "Iragazkia desgaituta dago",
-    "Operator" : "Eragilea",
     "contains" : "dauka",
-    "matches" : "bat dator",
-    "Delete test" : "Ezabatu proba",
-    "Update mail filter" : "Eguneratu posta iragazkia",
-    "Filter name" : "Iragaziaren izena",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Zure posta-zerbitzarian sartzen diren posta elektronikoei aplikatzen zaizkie probak. Eremu hauek probatzen dira: gaia (posta elektronikoaren gai-lerroa), bidaltzailea eta hartzailea. Honako eragile hauek erabil ditzakezu eremu horietarako baldintzak zehazteko:",
-    "An exact match. The field must be identical to the provided value." : "Bat etortze zehatza. Eremuak emandako balioaren berdina izan behar du.",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "Azpikate bat etortzea. Eremua bat dator emandako balioa barruan badago. Adibidez, \"aireportua\" bat etorriko litzake \"portua\"-rekin.",
+    "matches" : "bat dator",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "Patroi bat etortzea komodinak erabiliz. «*» sinboloa edozein karaktere (ezer ez barne) kopuru adierazten du. Bestalde, «?» karaktere bakarra adierazten du. Adibidez «*txosten*» «2024ko txostena»-rekin bat etorriko litzateke.",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "Ekintzak zehaztutako probak egiazkoak direnean abiarazten dira. Honako ekintza hauek daude:",
-    "Moves the message into a specified folder." : "Mezua karpeta zehatz batera eramaten du.",
-    "Adds a flag to the message." : "Bandera bat gehitzen dio mezuari.",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Iragazpen scriptaren exekuzioa geldiarazten du. Ekintza honen ondoren ez da iragazki gehiagorik prozesatuko.",
     "Priority" : "Lehentasuna",
     "Enable filter" : "Gaitu iragazkia",
-    "Save filter" : "Gorde iragazkia",
+    "Tag" : "Etiketa",
+    "delete" : "ezabatu",
+    "Edit" : "Editatu",
     "Successfully updated config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa behar bezala eguneratu da",
     "Error saving config" : "Errorea konfigurazioa gordetzean",
     "Saved config for \"{domain}\"" : "\"{domain}\"-ren konfigurazioa gorde da",
@@ -751,6 +741,18 @@ OC.L10N.register(
     "Looking for a way to encrypt your emails?" : "Zure mezu elektronikoak enkriptatzeko modu bat bilatzen ari zara?",
     "Install Mailvelope browser extension" : "Instalatu Mailvelope arakatzailearen luzapena",
     "Enable Mailvelope for the current domain" : "Gaitu Mailvelope uneko domeinurako",
-    "Go to newest message" : "Joan mezu berrienera"
+    "Flag" : "Bandera",
+    "The stop action ends all processing" : "Gelditze-ekintzak prozesua amaitzen du.",
+    "Operator" : "Eragilea",
+    "Delete test" : "Ezabatu proba",
+    "Update mail filter" : "Eguneratu posta iragazkia",
+    "Filter name" : "Iragaziaren izena",
+    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "Zure posta-zerbitzarian sartzen diren posta elektronikoei aplikatzen zaizkie probak. Eremu hauek probatzen dira: gaia (posta elektronikoaren gai-lerroa), bidaltzailea eta hartzailea. Honako eragile hauek erabil ditzakezu eremu horietarako baldintzak zehazteko:",
+    "An exact match. The field must be identical to the provided value." : "Bat etortze zehatza. Eremuak emandako balioaren berdina izan behar du.",
+    "Actions are triggered when the specified tests are true. The following actions are available:" : "Ekintzak zehaztutako probak egiazkoak direnean abiarazten dira. Honako ekintza hauek daude:",
+    "Moves the message into a specified folder." : "Mezua karpeta zehatz batera eramaten du.",
+    "Adds a flag to the message." : "Bandera bat gehitzen dio mezuari.",
+    "Halts the execution of the filter script. No further filters with will be processed after this action." : "Iragazpen scriptaren exekuzioa geldiarazten du. Ekintza honen ondoren ez da iragazki gehiagorik prozesatuko.",
+    "Save filter" : "Gorde iragazkia"
 },
 "nplurals=2; plural=(n != 1);");
