@@ -470,12 +470,12 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
     "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
     "Train" : "رشته",
-    "Flag" : "Flag",
     "Delete filter" : "Delete filter",
-    "Operator" : "عملگر",
     "contains" : "contains",
     "matches" : "مطابق است",
     "Priority" : "اولویت",
+    "delete" : "حذف",
+    "Edit" : "ویرایش",
     "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
     "Error saving config" : "Error saving config",
     "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
@@ -607,6 +607,7 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "ادامه دهید%s",
     "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
-    "Go to newest message" : "Go to newest message"
+    "Flag" : "Flag",
+    "Operator" : "عملگر"
 },
 "nplurals=2; plural=(n > 1);");
