@@ -12,6 +12,7 @@ OC.L10N.register(
     "To Do" : "Tehtävä",
     "Later" : "Myöhemmin",
     "Mail" : "Sähköposti",
+    "Mail Application" : "Sähköpostisovellus",
     "Mails" : "Sähköpostit",
     "💌 A mail app for Nextcloud" : "💌 Sähköpostisovellus Nextcloudille",
     "Your session has expired. The page will be reloaded." : "Istuntosi on vanhentunut. Sivu ladataan uudelleen.",
@@ -22,6 +23,8 @@ OC.L10N.register(
     "Connecting" : "Yhdistetään",
     "Reconnect Google account" : "Yhdistä Google-tili uudelleen",
     "Sign in with Google" : "Kirjaudu sisään Google-tililläsi",
+    "Reconnect Microsoft account" : "Yhdistä Microsoft-tili uudelleen",
+    "Sign in with Microsoft" : "Kirjaudu Microsoft-tilillä",
     "Save" : "Tallenna",
     "Connect" : "Yhdistä",
     "Looking up configuration" : "Etsitään määrityksiä",
@@ -69,8 +72,11 @@ OC.L10N.register(
     "Preferred writing mode for new messages and replies." : "Ensisijainen kirjoitustila uusissa viesteissä ja vastauksissa.",
     "Default folders" : "Oletuskansiot",
     "Autoresponder" : "Automaattivastaukset",
+    "Go to Sieve settings" : "Siirry Sieve-asetuksiin",
     "Filters" : "Suodattimet",
+    "Quick actions" : "Pikatoiminnot",
     "Mail server" : "Sähköpostipalvelin",
+    "Sieve server" : "Sieve-palvelin",
     "Update alias" : "Päivitä alias",
     "Delete alias" : "Poista alias",
     "Go back" : "Takaisin",
@@ -85,16 +91,32 @@ OC.L10N.register(
     "Accounts" : "Tilit",
     "Add mail account" : "Lisää sähköpostitili",
     "General" : "Yleiset",
+    "Layout" : "Asettelu",
+    "List" : "Lista",
+    "Vertical split" : "Pystysuunnan jako",
+    "Horizontal split" : "Vaakasuunnan jako",
+    "Message View Mode" : "Viestin näyttötapa",
+    "Show all messages in thread" : "Näytä kaikki viestit ketjussa",
+    "Show only the selected message" : "Näytä vain valittu viesti",
     "Sorting" : "Lajittelu",
     "Newest" : "Uusimmat",
     "Oldest" : "Vanhimmat",
+    "Search in body" : "Etsi sisällöstä",
+    "Gravatar settings" : "Gravatar-asetukset",
     "Use Gravatar and favicon avatars" : "Käytä Gravatar- ja favicon-avatareja",
     "Register as application for mail links" : "Rekisteröi sovellukseksi mail-linkeille",
     "Register" : "Rekisteröidy",
+    "Text blocks" : "Tekstilohkot",
+    "Create a new text block" : "Luo uusi tekstilohko",
     "Shared with me" : "Jaettu kanssasi",
+    "Privacy and security" : "Yksityisyys ja turvallisuus",
+    "Data collection consent" : "Datakeruun suostumus",
     "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "Salli sovelluksen kerätä tietoa vuorovaikutuksestasi. Tämän tiedon perusteella sovellus sopeutuu mieltymyksiisi. Nämä tiedot talletetaan vain paikallisesti.",
     "Trusted senders" : "Luotetut lähettäjät",
+    "S/MIME" : "S/MIME",
     "Manage S/MIME certificates" : "Hallitse S/MIME-varmenteita",
+    "Step 1: Install Mailvelope browser extension" : "Vaihe 1: Asenna Mailvelope-selainlaajennus",
+    "Step 2: Enable Mailvelope for the current domain" : "Vaihe 2: Ota Mailvelope käyttöön nykyiselle verkkotunnukselle",
     "About" : "Tietoja",
     "Keyboard shortcuts" : "Pikanäppäimet",
     "Compose new message" : "Uusi viesti",
@@ -107,6 +129,9 @@ OC.L10N.register(
     "Search" : "Etsi",
     "Send" : "Lähetä",
     "Refresh" : "Päivitä",
+    "New text block" : "Uusi tekstilohko",
+    "Title of the text block" : "Tekstilohkon otsikko",
+    "Content of the text block" : "Tekstilohkon sisältö",
     "Ok" : "Ok",
     "No certificate" : "Ei varmennetta",
     "Certificate updated" : "Varmenne päivitetty",
@@ -170,6 +195,7 @@ OC.L10N.register(
     "No messages" : "Ei viestejä",
     "Blind copy recipients only" : "Vain piilokopion vastaanottajat",
     "No subject" : "Ei aihetta",
+    "{markup-start}Draft:{markup-end} {subject}" : "{markup-start}Luonnos:{markup-end} {subject}",
     "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
     "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
     "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
@@ -178,8 +204,11 @@ OC.L10N.register(
     "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
     "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
+    "Could not execute quick action" : "Pikatoimintoa ei voitu suorittaa",
+    "Quick action executed" : "Pikatoiminto suoritettu",
     "Could not delete message" : "Ei voitu poistaa viestiä",
     "Could not archive message" : "Viestiä ei voitu arkistoida",
+    "This summary was AI generated" : "Tämä yhteenveto on tekoälyn luoma",
     "Encrypted message" : "Salattu viesti",
     "This message is unread" : "Tämä viesti on lukematon",
     "Unfavorite" : "Poista suosikeista",
@@ -192,6 +221,7 @@ OC.L10N.register(
     "Edit tags" : "Muokkaa tunnisteita",
     "Snooze" : "Torkuta",
     "Move thread" : "Siirrä ketju",
+    "Move Message" : "Siirrä viesti",
     "Archive thread" : "Arkistoi ketju",
     "Archive message" : "Arkistoi viesti",
     "Delete thread" : "Poista ketju",
@@ -202,10 +232,13 @@ OC.L10N.register(
     "Edit as new message" : "Muokkaa uutena viestinä",
     "Create task" : "Luo tehtävä",
     "Download message" : "Lataa viesti",
+    "Manage quick actions" : "Hallitse pikatoimintoja",
     "Load more" : "Lataa lisää",
     "_Mark {number} read_::_Mark {number} read_" : ["Merkitse {number} luetuksi","Merkitse {number} luetuksi"],
     "_Mark {number} unread_::_Mark {number} unread_" : ["Merkitse {number} lukemattomaksi","Merkitse {number} lukemattomaksi"],
     "_Mark {number} as important_::_Mark {number} as important_" : ["Merkitse {number} tärkeäksi","Merkitse {number} tärkeäksi"],
+    "_Mark {number} as spam_::_Mark {number} as spam_" : ["Merkitse {number} roskapostiksi","Merkitse {number} roskapostiksi"],
+    "_Move {number} thread_::_Move {number} threads_" : ["Siirrä {number} ketju","Siirrä {number} ketjua"],
     "Mark as unread" : "Merkitse lukemattomaksi",
     "Mark as read" : "Merkitse luetuksi",
     "Report this bug" : "Ilmoita viasta",
@@ -234,14 +267,20 @@ OC.L10N.register(
     "Decline" : "Kieltäydy",
     "Tentatively accept" : "Alustavasti hyväksytty",
     "More options" : "Lisää valintoja",
+    "Could not remove internal address {sender}" : "Ei voitu poistaa sisäistä osoitetta {sender}",
+    "Could not add internal address {address}" : "Ei voitu lisätä sisäistä osoitetta {address}",
     "individual" : "yksittäinen",
     "domain" : "domaini",
     "Remove" : "Poista",
     "email" : "sähköposti",
+    "Add internal address" : "Lisää sisäinen osoite",
     "Last hour" : "Viime tunti",
     "Today" : "Tänään",
+    "Yesterday" : "Eilen",
     "Last week" : "Viime viikko",
     "Last month" : "Viime kuukausi",
+    "Older" : "Vanhempi",
+    "Could not open folder" : "Kansiota ei voitu avata",
     "Loading messages …" : "Ladataan viestejä …",
     "Choose target folder" : "Valitse kohdekansio",
     "Important info" : "Tärkeää tietoa",
@@ -254,10 +293,13 @@ OC.L10N.register(
     "Translate" : "Käännä",
     "Forward message as attachment" : "Välitä viesti liitteenä",
     "View source" : "Näytä lähde",
+    "Print message" : "Tulosta viesti",
+    "Create mail filter" : "Luo viestisuodatin",
     "Download thread data for debugging" : "Lataa ketjun data vianjäljitystä varten",
     "Message body" : "Viestin runko",
     "Unnamed" : "Nimetön",
     "Embedded message" : "Upotettu viesti",
+    "calendar imported" : "kalenteri tuotu",
     "Choose a folder to store the attachment in" : "Valitse kansio liitetiedoston tallentamiselle",
     "Import into calendar" : "Tuo kalenteriin",
     "Download attachment" : "Lataa liite",
@@ -279,6 +321,8 @@ OC.L10N.register(
     "Moving" : "Siirretään",
     "Moving thread" : "Siirretään ketjua",
     "Moving message" : "Siirretään viestiä",
+    "Used quota: {quota}% ({limit})" : "Käytetty kiintiö: {quota}% ({limit})",
+    "Used quota: {quota}%" : "Käytetty kiintiö: {quota}%",
     "Remove account" : "Poista tili",
     "The account for {email} and cached email data will be removed from Nextcloud, but not from your email provider." : "Tili {email} ja tallennetut viesti poistetaan Nextcloudista, muttei sähköpostintarjoajaltasi.",
     "Remove {email}" : "Poista {email}",
@@ -323,16 +367,24 @@ OC.L10N.register(
     "Retry" : "Yritä uudelleen",
     "Warning sending your message" : "Varoitus viestiä lähettäessä",
     "Send anyway" : "Lähetä silti",
+    "Welcome to {productName} Mail" : "Tervetuloa {productName}-sähköpostiin ",
     "Autoresponder off" : "Automaattivastaukset pois päältä",
     "Autoresponder on" : "Automaattivastaukset päällä",
+    "Edit absence settings" : "Muokkaa poissaoloasetuksia",
     "First day" : "Ensimmäinen päivä",
     "Last day (optional)" : "Viimeinen päivä (valinnainen)",
     "Message" : "Viesti",
     "Oh Snap!" : "Oho!",
     "Save autoresponder" : "Tallenna automaattivastaus",
     "Pending or not sent messages will show up here" : "Odottavat tai vielä lähettämättömät viestit näkyvät täällä",
+    "Mail server error" : "Sähköpostipalvelimen virhe",
     "Message could not be sent" : "Viestiä ei voitu lähettää",
     "Message deleted" : "Viesti poistettu",
+    "Phishing email" : "Kalasteluviesti",
+    "This email might be a phishing attempt" : "Tämä viesti saattaa olla kalasteluyritys",
+    "Hide suspicious links" : "Piilota epäilyttävät linkit",
+    "Show suspicious links" : "Näytä epäilyttävät linkit",
+    "link text" : "linkin teksti",
     "Copied email address to clipboard" : "Sähköpostiosoite kopioitu leikepöydälle",
     "Could not copy email address to clipboard" : "Sähköpostiosoitetta ei voitu kopioida leikepöydälle",
     "Contacts with this address" : "Yhteystiedot tällä osoitteella",
@@ -344,6 +396,7 @@ OC.L10N.register(
     "Show less" : "Näytä vähemmän",
     "Show more" : "Näytä enemmän",
     "Clear" : "Tyhjennä",
+    "Search in folder" : "Etsi kansiosta",
     "Close" : "Sulje",
     "Body" : "Sisältö",
     "Date" : "Päivä",
@@ -359,12 +412,14 @@ OC.L10N.register(
     "Sieve User" : "Sieve-käyttäjä",
     "Sieve Password" : "Sieve-salasana",
     "Save sieve settings" : "Tallenna sieve-asetukset",
+    "The syntax seems to be incorrect:" : "Syntaksi vaikuttaa virheelliseltä:",
     "Signature …" : "Allekirjoitus…",
     "Your signature is larger than 2 MB. This may affect the performance of your editor." : "Allekirjoituksesi koko on yli kaksi megatavua. Tämä saattaa vaikuttaa muokkaimen suorituskykyyn.",
     "Save signature" : "Tallenna allekirjoitus",
     "Place signature above quoted text" : "Aseta allekirjoitus lainatun tekstin yläpuolelle",
     "Message source" : "Viestin lähde",
     "An error occurred, unable to rename the tag." : "Tapahtui virhe, tunnistetta ei voitu nimetä uudelleen.",
+    "Edit name or color" : "Muokkaa nimeä tai väriä",
     "Saving new tag name …" : "Tallennetaan uuden tunnisteen nimeä…",
     "Delete tag" : "Poista tunniste",
     "Tag name is a hidden system tag" : "Tunnisteen nimi on piilotettu järjestelmätunniste",
@@ -374,8 +429,11 @@ OC.L10N.register(
     "Add tag" : "Lisää tunniste",
     "Saving tag …" : "Tallennetaan tunnistetta…",
     "Task created" : "Tehtävä luotu",
+    "Could not create task" : "Tehtävää ei voitu luoda",
     "Could not load your message thread" : "Viestiketjua ei voitu ladata",
     "The thread doesn't exist or has been deleted" : "Ketjua ei ole olemassa tai se on poistettu",
+    "Print" : "Tulosta",
+    "Could not print message" : "Viestiä ei voitu tulostaa",
     "Loading thread" : "Ladataan ketjua",
     "Not found" : "Ei löytynyt",
     "Encrypted & verified " : "Salattu ja vahvistettu",
@@ -383,9 +441,17 @@ OC.L10N.register(
     "Signature unverified " : "Allekirjoitus vahvistamatta",
     "This message was encrypted by the sender before it was sent." : "Tämän viestin lähettäjä salasi viestin ennen sen lähettämistä.",
     "Reply all" : "Vastaa kaikille",
+    "Unsubscribe request sent" : "Tilauksen lopetuspyyntö lähetetty",
+    "Disable reminder" : "Poista muistutus käytöstä",
     "Unsubscribe" : "Peruuta tilaus",
     "Reply to sender only" : "Vastaa vain lähettäjälle",
     "Mark as favorite" : "Merkitse suosikiksi",
+    "Unsubscribe via link" : "Lopeta tilaus linkin kautta",
+    "Unsubscribing will stop all messages from the mailing list {sender}" : "Tilauksen lopettaminen pysäyttää kaikkien viestin saapumisen postituslistalta {sender}",
+    "Send unsubscribe email" : "Lähetä viesti tilauksen lopettamiseksi",
+    "Unsubscribe via email" : "Lopeta tilaus sähköpostiviestin välityksellä",
+    "Go to latest message" : "Siirry uusimpaan viestiin",
+    "Newest message" : "Uusin viesti",
     "The message could not be translated" : "Viestiä ei voitu kääntää",
     "Translation copied to clipboard" : "Käännös kopioitu leikepöydälle",
     "Translation could not be copied" : "Käännöstä ei voitu kopioida",
@@ -408,14 +474,42 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} asemalta {depStation} asemalle {arrStation}",
     "Train from {depStation} to {arrStation}" : "Juna asemalta {depStation} asemalle {arrStation}",
     "Train" : "Juna",
-    "Flag" : "Lippu",
+    "Delete action" : "Poista toiminto",
+    "Sender" : "Lähettäjä",
     "Recipient" : "Vastaanottaja",
+    "Create a new mail filter" : "Luo uusi viestisuodatin",
     "Delete filter" : "Poista suodatin",
-    "Operator" : "Operaattori",
+    "Delete mail filter {filterName}?" : "Poistetaanko viestisuodatin {filterName}?",
+    "Are you sure to delete the mail filter?" : "Haluatko varmasti poistaa viestisuodattimen?",
+    "New filter" : "Uusi suodatin",
+    "Filter saved" : "Suodatin tallennettu",
+    "Could not save filter" : "Suodatinta ei voitu tallentaa",
+    "Filter deleted" : "Suodatin poistettu",
+    "Could not delete filter" : "Suodatinta ei voitu poistaa",
+    "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "Ota postikaaos hallintaan. Suodattimet auttavat asettamaan asioita tärkeysjärjestykseen ja minimoimaan turhuudet.",
+    "Filter is active" : "Suodatin on aktiivinen",
+    "Filter is not active" : "Suodatin ei ole aktiivinen",
     "contains" : "sisältää",
     "matches" : "täsmää",
-    "Filter name" : "Nimisuodatin",
+    "Add condition" : "Lisää ehto",
+    "Add action" : "Lisää toiminto",
     "Priority" : "Tärkeys",
+    "Enable filter" : "Käytä suodatinta",
+    "Tag" : "Tunniste",
+    "delete" : "poista",
+    "Edit quick action" : "Muokkaa pikatoimintoa",
+    "Add quick action" : "Lisää pikatoiminto",
+    "Quick action deleted" : "Pikatoiminto poistettu",
+    "Failed to delete quick action" : "Pikatoiminnon poisto epäonnistui",
+    "Failed to update quick action" : "Pikatoiminnon päivitys epäonnistui",
+    "Quick action updated" : "Pikatoiminto päivitetty",
+    "Failed to create quick action" : "Pikatoiminnon luonti epäonnistui",
+    "Quick action created" : "Pikatoiminto luotu",
+    "No quick actions yet." : "Ei pikatoimintoja vielä",
+    "Edit" : "Muokkaa",
+    "Quick action name" : "Pikatoiminnon nimi",
+    "Do the following actions" : "Tee seuraavat toiminnot",
+    "Add another action" : "Lisää toinen toiminto",
     "Mail app" : "Sähköpostisovellus",
     "The mail app allows users to read mails on their IMAP accounts." : "Tämä sähköpostisovellus mahdollistaa käyttäjien lukea sähköpostiviestejä IMAP-tileiltä.",
     "Account provisioning" : "Käyttäjän provisiointi",
@@ -463,10 +557,20 @@ OC.L10N.register(
     "Certificate" : "Varmenne",
     "Private key (optional)" : "Yksityinen avain (valinnainen)",
     "Submit" : "Lähetä",
+    "No text blocks available" : "Tekstilohkoja ei ole saatavilla",
+    "Text block deleted" : "Tekstilohko poistettu",
+    "Failed to delete text block" : "Tekstilohkon poisto epäonnistui",
+    "Guest" : "Vieras",
     "Group" : "Ryhmä",
+    "Failed to save text block" : "Tekstilohkon tallennus epäonnistui",
     "Shared" : "Jaettu",
+    "Edit {title}" : "Muokkaa {title}",
+    "Delete {title}" : "Poista {title}",
+    "Edit text block" : "Muokkaa tekstilohkoa",
     "Shares" : "Jaot",
+    "Search for users or groups" : "Etsi käyttäjiä tai ryhmiä",
     "Insert" : "Lisää",
+    "Insert text block" : "Lisää tekstilohko",
     "Account connected" : "Tili yhdistetty",
     "You can close this window" : "Voit sulkea tämän ikkunan",
     "Connect your mail account" : "Yhdistä sähköpostitilisi",
@@ -489,6 +593,7 @@ OC.L10N.register(
     "Discard unsaved changes" : "Hylkää tallentamattomat muutokset",
     "Keep editing message" : "Jatka viestin muokkausta",
     "Attachments were not copied. Please add them manually." : "Liitetiedostoja ei kopiotu. Lisää ne manuaalisesti.",
+    "Sending message…" : "Lähetetään viestiä…",
     "Message sent" : "Viesti lähetetty",
     "Could not send message" : "Viestiä ei voitu lähettää",
     "Could not load {tag}{name}{endtag}" : "{tag}{name}{endtag} ei voitu ladata",
@@ -503,6 +608,15 @@ OC.L10N.register(
     "The link leads to %s" : "Tämä linkki johtaa kohteeseen %s",
     "Continue to %s" : "Jatka sivulle %s",
     "Looking for a way to encrypt your emails?" : "Etsitkö tapaa salata sähköpostisi?",
-    "Install Mailvelope browser extension" : "Asenna Mailvelope-selainlaajennus"
+    "Install Mailvelope browser extension" : "Asenna Mailvelope-selainlaajennus",
+    "Flag" : "Lippu",
+    "Operator" : "Operaattori",
+    "Update mail filter" : "Päivitä viestisuodatin",
+    "Filter name" : "Nimisuodatin",
+    "If all the conditions are met" : "jos kaikki ehdot ovat tosia",
+    "If any of the conditions are met" : "jos yksi ehdoista on tosi",
+    "Then perform these actions" : "Sitten suorita nämä toiminnot",
+    "Moves the message into a specified folder." : "Siirtää viestin haluttuun kansioon.",
+    "Save filter" : "Tallenna suodatin"
 },
 "nplurals=2; plural=(n != 1);");
