@@ -223,6 +223,9 @@ OC.L10N.register(
     "Train" : "רכבת",
     "matches" : "תואם",
     "Priority" : "עדיפות",
+    "Tag" : "תגית",
+    "delete" : "מחיקה",
+    "Edit" : "עריכה",
     "Mail app" : "יישומון דוא״ל",
     "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
     "Reset" : "איפוס",
