@@ -285,6 +285,9 @@ OC.L10N.register(
     "Recipient" : "Primatelj",
     "matches" : "podudara se",
     "Priority" : "Prioritet",
+    "Tag" : "Oznaka",
+    "delete" : "izbriši",
+    "Edit" : "Uredi",
     "Successfully updated config for \"{domain}\"" : "Konfiguracija za „{domain}“ je uspješno ažurirana",
     "Error saving config" : "Pogreška pri spremanju konfiguracije",
     "Saved config for \"{domain}\"" : "Konfiguracija za „{domain}“ je spremljena",
