@@ -490,14 +490,14 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} vonat {depStation} és {arrStation} között",
     "Train from {depStation} to {arrStation}" : "Vonat {depStation} és {arrStation} között",
     "Train" : "Vonat",
-    "Flag" : "Zászló",
     "Recipient" : "Címzett",
     "Delete filter" : "Szűrő törlése",
-    "Operator" : "Állapot",
     "contains" : "tartalmazza",
     "matches" : "egyezik",
-    "Filter name" : "Név szűrése",
     "Priority" : "Prioritás",
+    "Tag" : "Címke",
+    "delete" : "töröl",
+    "Edit" : "Szerkesztés",
     "Successfully updated config for \"{domain}\"" : "A(z) „{domain}” konfigurációja sikeresen frissítve",
     "Error saving config" : "Hiba a konfiguráció mentése során",
     "Saved config for \"{domain}\"" : "Konfiguráció mentése ehhez: „{domain}”",
@@ -642,6 +642,8 @@ OC.L10N.register(
     "Continue to %s" : "Folytatás ide: %s",
     "Looking for a way to encrypt your emails?" : "Azt keresi, hogyan titkosíthatná a leveleit?",
     "Install Mailvelope browser extension" : "Telepítse a Mailvelope böngészőkiegészítőt",
-    "Go to newest message" : "Ugrás a legújabb üzenethez"
+    "Flag" : "Zászló",
+    "Operator" : "Állapot",
+    "Filter name" : "Név szűrése"
 },
 "nplurals=2; plural=(n != 1);");
