@@ -416,12 +416,13 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} da {depStation} a {arrStation}",
     "Train from {depStation} to {arrStation}" : "Treno da {depStation} a {arrStation}",
     "Train" : "Treno",
-    "Flag" : "Bandiera",
     "Recipient" : "Destinatario",
-    "Operator" : "Operatore",
     "contains" : "contiene",
     "matches" : "corrisponde",
     "Priority" : "Priorità",
+    "Tag" : "Etichetta",
+    "delete" : "elimina",
+    "Edit" : "Modifica",
     "Successfully updated config for \"{domain}\"" : "Configurazione aggiornata con successo per \"{domain}\"",
     "Error saving config" : "Errore durante il salvataggio della configurazione",
     "Saved config for \"{domain}\"" : "Configurazione salvata per \"{domain}\"",
@@ -557,6 +558,7 @@ OC.L10N.register(
     "Redirect" : "Redirigi",
     "The link leads to %s" : "Il collegamento conduce a %s",
     "Continue to %s" : "Continua su %s",
-    "Go to newest message" : "Vai al messaggio più recente"
+    "Flag" : "Bandiera",
+    "Operator" : "Operatore"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
