@@ -544,9 +544,8 @@ OC.L10N.register(
     "Send unsubscribe email" : "配信停止メールを送信する",
     "Unsubscribe via email" : "メールで購読を解除する",
     "{name} Assistant" : "{name}アシスタント",
-    "Go to latest message" : "最新のメッセージへ移動",
-    "Go to newest message" : "一番新しいメッセージへ移動",
     "Thread summary" : "スレッドの概要",
+    "Go to latest message" : "最新のメッセージへ移動",
     "Please select languages to translate to and from" : "翻訳する言語を選択してください",
     "The message could not be translated" : "メッセージは翻訳できませんでした",
     "Translation copied to clipboard" : "翻訳をクリップボードにコピーしました",
@@ -572,8 +571,6 @@ OC.L10N.register(
     "Train from {depStation} to {arrStation}" : "{depStation} から {arrStation} 行きの列車",
     "Train" : "列車",
     "Delete action" : "アクションを削除",
-    "Flag" : "フラグ",
-    "The stop action ends all processing" : "stop アクションは、すべての処理を終了します",
     "Recipient" : "受信者",
     "Delete filter" : "フィルターを削除",
     "Delete mail filter {filterName}?" : "メールフィルター{filterName}を削除しますか？",
@@ -586,23 +583,15 @@ OC.L10N.register(
     "Take control of your email chaos. Filters help you to prioritize what matters and eliminate clutter." : "メールの混乱をコントロールしましょう。フィルタを使えば、重要なものに優先順位をつけ、乱雑さを解消できます。",
     "Filter is active" : "フィルターが有効",
     "Filter is not active" : "フィルターが無効",
-    "Operator" : "条件",
     "contains" : "を含む",
-    "matches" : "一致",
-    "Delete test" : "テストを削除",
-    "Update mail filter" : "メールフィルターを更新する",
-    "Filter name" : "フィルター名",
-    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "テストは、Subject（メールの件名）、From（送信者）、To（受信者）などのフィールドを対象として、メールサーバー上の受信メールに適用されます。以下の演算子を使用して、これらのフィールドの条件を定義できます：",
-    "An exact match. The field must be identical to the provided value." : "完全一致。フィールドは提供された値と同一でなければなりません。",
     "A substring match. The field matches if the provided value is contained within it. For example, \"report\" would match \"port\"." : "部分文字列のマッチ。提供された値がそのフィールドに含まれる場合にマッチする。例えば、「report 」は 「port 」にマッチする。",
+    "matches" : "一致",
     "A pattern match using wildcards. The \"*\" symbol represents any number of characters (including none), while \"?\" represents exactly one character. For example, \"*report*\" would match \"Business report 2024\"." : "ワイルドカードを使ったパターン・マッチ。記号 「*」は任意の文字数（ない場合も含む）を表し、「? 」は正確に1文字を表す。例えば、「*report*」は 「Business report 2024 」にマッチする。",
-    "Actions are triggered when the specified tests are true. The following actions are available:" : "アクションは、指定されたテストが真であるときにトリガーされる。以下のアクションが利用可能です：",
-    "Moves the message into a specified folder." : "メッセージを指定したフォルダーに移動します。",
-    "Adds a flag to the message." : "メッセージにフラグを追加する。",
-    "Halts the execution of the filter script. No further filters with will be processed after this action." : "フィルタースクリプトの実行を停止する。この操作の後、それ以降のフィルターは処理されません。",
     "Priority" : "優先度",
     "Enable filter" : "フィルターを有効にする",
-    "Save filter" : "フィルターを保存する",
+    "Tag" : "タグ",
+    "delete" : "削除",
+    "Edit" : "編集",
     "Successfully updated config for \"{domain}\"" : " \"{domain}\"の設定が正常に更新されました",
     "Error saving config" : "設定の保存中にエラーが発生しました",
     "Saved config for \"{domain}\"" : "\"{domain}\"の設定を保存しました",
@@ -754,6 +743,19 @@ OC.L10N.register(
     "Continue to %s" : "%s にリダイレクトする",
     "Mailvelope is enabled for the current domain!" : "現在のドメインでMailvelopeが有効になっています!",
     "Looking for a way to encrypt your emails?" : "あなたのメールを暗号化する方法をお探しですか?",
-    "Enable Mailvelope for the current domain" : "現在のドメインのMailvelopeを有効にする"
+    "Enable Mailvelope for the current domain" : "現在のドメインのMailvelopeを有効にする",
+    "Flag" : "フラグ",
+    "The stop action ends all processing" : "stop アクションは、すべての処理を終了します",
+    "Operator" : "条件",
+    "Delete test" : "テストを削除",
+    "Update mail filter" : "メールフィルターを更新する",
+    "Filter name" : "フィルター名",
+    "Tests are applied to incoming emails on your mail server, targeting fields such as subject (the email's subject line), from (the sender), and to (the recipient). You can use the following operators to define conditions for these fields:" : "テストは、Subject（メールの件名）、From（送信者）、To（受信者）などのフィールドを対象として、メールサーバー上の受信メールに適用されます。以下の演算子を使用して、これらのフィールドの条件を定義できます：",
+    "An exact match. The field must be identical to the provided value." : "完全一致。フィールドは提供された値と同一でなければなりません。",
+    "Actions are triggered when the specified tests are true. The following actions are available:" : "アクションは、指定されたテストが真であるときにトリガーされる。以下のアクションが利用可能です：",
+    "Moves the message into a specified folder." : "メッセージを指定したフォルダーに移動します。",
+    "Adds a flag to the message." : "メッセージにフラグを追加する。",
+    "Halts the execution of the filter script. No further filters with will be processed after this action." : "フィルタースクリプトの実行を停止する。この操作の後、それ以降のフィルターは処理されません。",
+    "Save filter" : "フィルターを保存する"
 },
 "nplurals=1; plural=0;");
