@@ -494,9 +494,9 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} from {depStation} to {arrStation}",
     "Train from {depStation} to {arrStation}" : "Train from {depStation} to {arrStation}",
     "Train" : "Train",
-    "Operator" : "ოპერატორი",
     "matches" : "matches",
     "Priority" : "Priority",
+    "Edit" : "Edit",
     "Successfully updated config for \"{domain}\"" : "Successfully updated config for \"{domain}\"",
     "Error saving config" : "Error saving config",
     "Saved config for \"{domain}\"" : "Saved config for \"{domain}\"",
@@ -640,6 +640,6 @@ OC.L10N.register(
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>.",
     "Continue to %s" : "Continue to %s",
     "Looking for a way to encrypt your emails?" : "Looking for a way to encrypt your emails?",
-    "Go to newest message" : "Go to newest message"
+    "Operator" : "ოპერატორი"
 },
 "nplurals=2; plural=(n!=1);");
