@@ -502,14 +502,13 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 {trainNr}번 열차",
     "Train from {depStation} to {arrStation}" : "{depStation}에서 {arrStation}(으)로 향하는 열차",
     "Train" : "기차",
-    "Flag" : "깃발",
     "Recipient" : "받는 사람",
     "Delete filter" : "필터 삭제",
-    "Operator" : "운영자",
     "contains" : "다음을 포함함",
     "matches" : "일치함",
-    "Filter name" : "필터 이름",
     "Priority" : "우선 순위",
+    "delete" : "삭제",
+    "Edit" : "편집",
     "Successfully updated config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 성공적으로 갱신함",
     "Error saving config" : "설정을 저장하는 중 오류 발생",
     "Saved config for \"{domain}\"" : "\"{domail}\"에 대한 설정을 저장함",
@@ -662,6 +661,8 @@ OC.L10N.register(
     "Looking for a way to encrypt your emails?" : "이메일을 암호화하는 방법을 찾고 계십니까?",
     "Install Mailvelope browser extension" : "Mailvelope 브라우저 확장 설치",
     "Enable Mailvelope for the current domain" : "현재 도메인에 Mailvelope 활성화하기",
-    "Go to newest message" : "최근 메시지로 가기"
+    "Flag" : "깃발",
+    "Operator" : "운영자",
+    "Filter name" : "필터 이름"
 },
 "nplurals=1; plural=0;");
