@@ -10,6 +10,7 @@ OC.L10N.register(
     "Mail" : "E-pasts",
     "Mails" : "E-pasta sūtījumi",
     "💌 A mail app for Nextcloud" : "Nextcloud e-pasta lietotne",
+    "Your session has expired. The page will be reloaded." : "Sesijai ir beidzies derīgums. Lapa tiks pārlādēta.",
     "Connecting" : "Savienojuma izveide",
     "Save" : "Saglabāt",
     "Connect" : "Savienoties",
@@ -137,10 +138,12 @@ OC.L10N.register(
     "Not found" : "Nav atrasts",
     "Untitled event" : "Nenosaukts notikums",
     "Recipient" : "Saņēmējs",
-    "Operator" : "Operators",
     "contains" : "saturs",
     "matches" : "atbilst",
     "Priority" : "Svarīgums",
+    "Tag" : "Birkas",
+    "delete" : "dzēst",
+    "Edit" : "Labot",
     "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
     "Reset" : "Atiestatīt",
     "Client ID" : "Klienta ID",
@@ -175,6 +178,7 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
     "Redirect" : "Novirzīt",
     "The link leads to %s" : "Saite, kas ved uz %s",
-    "Continue to %s" : "Turpināt %s"
+    "Continue to %s" : "Turpināt %s",
+    "Operator" : "Operators"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
