@@ -403,9 +403,10 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} од {depStation} до {arrStation}",
     "Train from {depStation} to {arrStation}" : "Воз од  {depStation} до {arrStation}",
     "Train" : "Воз",
-    "Flag" : "Знаме",
     "matches" : "се совпаѓа",
     "Priority" : "Приоритет",
+    "delete" : "избриши",
+    "Edit" : "Уреди",
     "Mail app" : "Апликација Електронска пошта",
     "The mail app allows users to read mails on their IMAP accounts." : "Апликацијата за електронска пошта дозволува на корисниците да ги читаат својте пораки од IMAP сметки.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Овде може да се пронајде поопшитно прилагодување. Специфични параметри за корисниците може да се пронајдат во самата апликација (доле-лево).",
@@ -481,6 +482,7 @@ OC.L10N.register(
     "Redirect" : "Пренасочи",
     "The link leads to %s" : "Линкот води кон %s",
     "If you do not want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Доколку несакате да ја посетите страната, можете да се вратите кон <a href=\"%s\">Е-пошта</a>.",
-    "Continue to %s" : "Продолжи до %s"
+    "Continue to %s" : "Продолжи до %s",
+    "Flag" : "Знаме"
 },
 "nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
