@@ -554,14 +554,13 @@ OC.L10N.register(
     "{trainNr} from {depStation} to {arrStation}" : "{trainNr} fra {depStation} til {arrStation}\n ",
     "Train from {depStation} to {arrStation}" : "Tog fra {depStation} til {arrStation}\n ",
     "Train" : "Tog",
-    "Flag" : "Flagg",
     "Recipient" : "Mottaker",
     "Delete filter" : "Slett filter",
-    "Operator" : "Operator",
     "contains" : "inneholder",
     "matches" : "passer",
-    "Filter name" : "Filternavn",
     "Priority" : "Prioritet",
+    "delete" : "slett",
+    "Edit" : "Rediger",
     "Successfully updated config for \"{domain}\"" : "Vellykket oppdatert konfigurasjon for «{domain}»",
     "Error saving config" : "Feil ved lagring av konfigurasjon",
     "Saved config for \"{domain}\"" : "Lagret konfigurasjon for «{domain}»",
@@ -714,6 +713,8 @@ OC.L10N.register(
     "Mailvelope is enabled for the current domain!" : "Mailvelope er aktivert for gjeldende domene!",
     "Looking for a way to encrypt your emails?" : "Leter du etter en måte å kryptere e-postene dine på?",
     "Enable Mailvelope for the current domain" : "Aktiver Mailvelope for gjeldende domene",
-    "Go to newest message" : "Gå til nyeste melding"
+    "Flag" : "Flagg",
+    "Operator" : "Operator",
+    "Filter name" : "Filternavn"
 },
 "nplurals=2; plural=(n != 1);");
