@@ -91,7 +91,8 @@ OC.L10N.register(
     "Translating" : "Traduccion",
     "Untitled event" : "Eveniment sens títol",
     "Train" : "Tren",
-    "Flag" : "Drapèu",
+    "delete" : "suprimir",
+    "Edit" : "Modificar",
     "Reset" : "Reïnicializar",
     "Client ID" : "ID client",
     "User" : "Utilizator",
@@ -117,6 +118,7 @@ OC.L10N.register(
     "{from}\n{subject}" : "{from}\n{subject}",
     "Message sent" : "Messatge mandat",
     "Error loading message" : "Error al moment del cargament del messatge",
-    "Continue to %s" : "Contunhar cap a %s"
+    "Continue to %s" : "Contunhar cap a %s",
+    "Flag" : "Drapèu"
 },
 "nplurals=2; plural=(n > 1);");
