@@ -198,11 +198,12 @@ OC.L10N.register(
     "Reservation {id}" : "Reserva {id}",
     "Train" : "Comboio",
     "Recipient" : "Destinatário",
-    "Operator" : "Operador",
     "contains" : "contém",
     "matches" : "corresponde",
-    "Filter name" : "Filtrar nome",
     "Priority" : "Prioridade",
+    "Tag" : "Etiqueta",
+    "delete" : "eliminar",
+    "Edit" : "Editar",
     "Reset" : "Reiniciar",
     "Client ID" : "Id. de Cliente",
     "Client secret" : "Segredo de cliente",
@@ -243,6 +244,8 @@ OC.L10N.register(
     "Click here if you are not automatically redirected within the next few seconds." : "Clique aqui se não for automaticamente redirecionado dentro de segundos.",
     "Redirect" : "Redirecionar",
     "The link leads to %s" : "A ligação aponta para %s",
-    "Continue to %s" : "Continuar para %s"
+    "Continue to %s" : "Continuar para %s",
+    "Operator" : "Operador",
+    "Filter name" : "Filtrar nome"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
