@@ -17,6 +17,7 @@ OC.L10N.register(
     "Search" : "Search",
     "Send" : "Pošalji",
     "Refresh" : "Osveži",
+    "Ok" : "Ok",
     "Select account" : "Označite nalog",
     "Choose" : "Odaberi",
     "Favorite" : "Omiljene",
@@ -27,6 +28,9 @@ OC.L10N.register(
     "Select" : "Obeleži",
     "Comment" : "Komentar",
     "Remove" : "Ukloni",
+    "Today" : "Danas",
+    "Yesterday" : "јуче",
+    "Last month" : "Prošlog meseca",
     "Other" : "Ostali",
     "Forward" : "Prosledi",
     "Translate" : "Prevedi",
@@ -44,7 +48,10 @@ OC.L10N.register(
     "Date" : "Date",
     "Tags" : "Oznake",
     "Not found" : "Nije nađeno",
+    "delete" : "obriši",
+    "Edit" : "Izmeni",
     "User" : "Korisnik",
+    "Shared" : "Deljeno",
     "All" : "Sve",
     "Favorites" : "Omiljene",
     "Continue to %s" : "Nastavi na %s"
