@@ -13,6 +13,7 @@ OC.L10N.register(
     "Auto" : "Auto",
     "Name" : "Jina",
     "Password" : "Nenosiri",
+    "Manual" : "Manual",
     "None" : "Hakuna",
     "Signature" : "Saini",
     "Filters" : "Filters",
@@ -36,6 +37,7 @@ OC.L10N.register(
     "From" : "Tangu/ kutoka",
     "Select account" : "Chagua akaunti",
     "To" : "Mpaka/ hadi",
+    "Subject" : "Subject",
     "Smart picker" : "Smart picker",
     "Choose" : "Chagua",
     "Choose a file to add as attachment" : "Chagua faili kuongeza kama kiambatanisho",
@@ -127,10 +129,10 @@ OC.L10N.register(
     "Copy translated text" : "Nakili maandishi yaliyotafsiriwa",
     "Untitled event" : "Tukio lisilotajwa",
     "(organizer)" : "(Mratibu)",
-    "Operator" : "Operator",
     "contains" : "contains",
     "matches" : "matches",
     "Priority" : "Kipaumbele",
+    "Edit" : "Hariri",
     "Reset" : "Pangilia upya",
     "Client ID" : "Kitambulisho cha mteja",
     "Client secret" : "Siri ya mteja",
@@ -152,6 +154,7 @@ OC.L10N.register(
     "Discard changes" : "Discard changes",
     "Message sent" : "Ujumbe umetumwa",
     "Redirect" : "Elekeza upya",
-    "Continue to %s" : "Endelea katika %s"
+    "Continue to %s" : "Endelea katika %s",
+    "Operator" : "Operator"
 },
 "nplurals=2; plural=(n != 1);");
