@@ -10,28 +10,39 @@ OC.L10N.register(
     "Password" : "கடவுச்சொல்",
     "None" : "ஒன்றுமில்லை",
     "Cancel" : "இரத்து செய்க",
+    "Accounts" : "Accounts",
     "General" : "பொதுவான",
     "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
     "Delete" : "நீக்குக",
     "Search" : "Search",
     "Refresh" : "மீள் ஏற்றுக",
+    "Ok" : "Ok",
     "Choose" : "தெரிவுசெய்க ",
     "Favorite" : "விருப்பமான",
     "Back" : "பின்னுக்கு",
+    "Attendees" : "பங்கேற்பாளர்கள்",
     "Description" : "விவரிப்பு",
     "Create" : "உருவாக்குக",
     "Select" : "Select",
     "Remove" : "அகற்றுக",
+    "Today" : "இன்று",
+    "Yesterday" : "நேற்று",
     "Other" : "மற்றவை",
     "Translate" : "Translate",
     "Move" : "Move",
-    "Quota" : "பங்கு",
+    "Folder name" : "கோப்புறை பெயர்",
     "Saving" : "Saving",
     "Rename" : "பெயர்மாற்றம்",
     "Add" : "சேர்க்க",
     "Close" : "மூடுக",
     "Date" : "Date",
     "Tags" : "சீட்டுகள்",
+    "delete" : "நீக்குக",
+    "Edit" : "தொகுக்க",
+    "User" : "User",
+    "Host" : "ஓம்புனர்",
+    "Port" : "துறை ",
+    "Group" : "Group",
     "All" : "எல்லாம்",
     "Favorites" : "விருப்பங்கள்"
 },
