@@ -17,6 +17,7 @@ OC.L10N.register(
     "List" : "Ro`yxat",
     "Register" : "Roʻyxatdan oʻtish",
     "About" : "About",
+    "Keyboard shortcuts" : "Klaviatura yorliqlari",
     "Archive" : "Arxiv",
     "Delete" : "O'chirish",
     "Search" : "Qidirish",
@@ -59,6 +60,7 @@ OC.L10N.register(
     "Rename" : "Nomini o'zgartirish",
     "Subscribed" : "Obuna boʻlgan",
     "Reply" : "Javob bering",
+    "Retry" : "Qayta urinish",
     "Add" : "Add",
     "Close" : "Yopish",
     "Date" : "Sana",
@@ -69,16 +71,18 @@ OC.L10N.register(
     "Not found" : "Topilmadi",
     "Untitled event" : "Nomsiz tadbir",
     "(organizer)" : "(tashkilotchi)",
-    "Operator" : "Operator",
     "contains" : "o'z ichiga oladi",
+    "Edit" : "Tahrirlash",
     "Reset" : "Qayta tiklash",
     "Client ID" : "Mijoz identifikatori",
     "Port" : "Port",
+    "Submit" : "Submit",
     "Shared" : "Ulashilgan",
     "Account connected" : "Akkaunt ulangan",
     "All" : "All",
     "Favorites" : "Favorites",
     "Error while sharing file" : "Fayl almashishda xatolik yuz berdi",
-    "Continue to %s" : " %sni davom eting"
+    "Continue to %s" : " %sni davom eting",
+    "Operator" : "Operator"
 },
 "nplurals=1; plural=0;");
