@@ -234,6 +234,8 @@ OC.L10N.register(
     "Delete filter" : "Xóa bộ lọc ",
     "contains" : "chứa",
     "matches" : "so sánh",
+    "delete" : "xóa",
+    "Edit" : "Chỉnh sửa",
     "Mail app" : "Ứng dụng thư",
     "The mail app allows users to read mails on their IMAP accounts." : "Ứng dụng thư cho phép người dùng đọc thư trên tài khoản IMAP của họ.",
     "Here you can find instance-wide settings. User specific settings are found in the app itself (bottom-left corner)." : "Tại đây bạn có thể tìm thấy các cài đặt cho toàn phiên bản. Cài đặt người dùng cụ thể được tìm thấy trong chính ứng dụng (góc dưới bên trái).",
