@@ -11,6 +11,7 @@ declare(strict_types=1);
 namespace OCA\Mail\Controller;
 
 use Horde_Imap_Client;
+use OCA\Mail\AppInfo\Application;
 use OCA\Mail\Contracts\IMailManager;
 use OCA\Mail\Contracts\IMailSearch;
 use OCA\Mail\Exception\ClientException;
@@ -27,29 +28,27 @@ use OCP\AppFramework\Http\Attribute\NoAdminRequired;
 use OCP\AppFramework\Http\Attribute\OpenAPI;
 use OCP\AppFramework\Http\Attribute\UserRateLimit;
 use OCP\AppFramework\Http\JSONResponse;
+use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\IConfig;
 use OCP\IRequest;
 
 #[OpenAPI(scope: OpenAPI::SCOPE_IGNORE)]
 class MailboxesController extends Controller {
 	private AccountService $accountService;
-	private ?string $currentUserId;
 	private IMailManager $mailManager;
 	private SyncService $syncService;
+	private ?string $currentUserId;
 
-	/**
-	 * @param string $appName
-	 * @param IRequest $request
-	 * @param AccountService $accountService
-	 * @param string|null $UserId
-	 * @param IMailManager $mailManager
-	 * @param SyncService $syncService
-	 */
-	public function __construct(string $appName,
+	public function __construct(
+		string $appName,
 		IRequest $request,
 		AccountService $accountService,
 		?string $UserId,
 		IMailManager $mailManager,
-		SyncService $syncService) {
+		SyncService $syncService,
+		private readonly IConfig $config,
+		private readonly ITimeFactory $timeFactory,
+	) {
 		parent::__construct($appName, $request);
 
 		$this->accountService = $accountService;
@@ -140,6 +139,13 @@ class MailboxesController extends Controller {
 		$account = $this->accountService->find($this->currentUserId, $mailbox->getAccountId());
 		$order = $sortOrder === 'newest' ? IMailSearch::ORDER_NEWEST_FIRST: IMailSearch::ORDER_OLDEST_FIRST;
 
+		$this->config->setUserValue(
+			$this->currentUserId,
+			Application::APP_ID,
+			'ui-heartbeat',
+			(string)$this->timeFactory->getTime(),
+		);
+
 		try {
 			$syncResponse = $this->syncService->syncMailbox(
 				$account,
