@@ -90,8 +90,9 @@ class OutboxController extends Controller {
 	public function create(
 		int $accountId,
 		string $subject,
-		string $body,
-		string $editorBody,
+		?string $bodyPlain,
+		?string $bodyHtml,
+		?string $editorBody,
 		bool $isHtml,
 		bool $smimeSign,
 		bool $smimeEncrypt,
@@ -118,9 +119,10 @@ class OutboxController extends Controller {
 		$message->setAccountId($accountId);
 		$message->setAliasId($aliasId);
 		$message->setSubject($subject);
-		$message->setBody($body);
-		$message->setEditorBody($editorBody);
+		$message->setBodyPlain($bodyPlain);
+		$message->setBodyHtml($bodyHtml);
 		$message->setHtml($isHtml);
+		$message->setEditorBody($editorBody);
 		$message->setInReplyToMessageId($inReplyToMessageId);
 		$message->setSendAt($sendAt);
 		$message->setPgpMime($isPgpMime);
@@ -181,7 +183,8 @@ class OutboxController extends Controller {
 		int $id,
 		int $accountId,
 		string $subject,
-		string $body,
+		?string $bodyPlain,
+		?string $bodyHtml,
 		?string $editorBody,
 		bool $isHtml,
 		bool $smimeSign,
@@ -207,9 +210,10 @@ class OutboxController extends Controller {
 		$message->setAccountId($accountId);
 		$message->setAliasId($aliasId);
 		$message->setSubject($subject);
-		$message->setBody($body);
-		$message->setEditorBody($editorBody);
+		$message->setBodyPlain($bodyPlain);
+		$message->setBodyHtml($bodyHtml);
 		$message->setHtml($isHtml);
+		$message->setEditorBody($editorBody);
 		$message->setInReplyToMessageId($inReplyToMessageId);
 		$message->setSendAt($sendAt);
 		$message->setPgpMime($isPgpMime);
